Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Emitter ¶
type Emitter struct {
// contains filtered or unexported fields
}
Emitter represents an event emitter.
func (*Emitter) Emit ¶
Emit runs callbacks for the specified event name, and ensures that one-off events, are removed when the event has finished emitting.
Click to show internal directories.
Click to hide internal directories.